#' Local Projection Impulse Response Functions
#'
#' lpirfs provides functions to estimate and plot linear as well as nonlinear impulse
#' responses based on local projections by Jordà (2005) <doi:10.1257/0002828053828518>.
#' The methods and the package are explained in detail in Adämmer (2019) <doi:10.32614/RJ-2019-052>.
#' Please cite the paper when using the package.
#'
#' @author Philipp Adämmer
#' @importFrom Rcpp evalCpp
#' @useDynLib lpirfs, .registration = TRUE
#' @exportPattern "^[[:alpha:]]+"
#' @name lpirfs-package
"_PACKAGE"
